import React, { Component } from 'react';
import Uuid from 'uuid';
import classnames from 'classnames';
import noop from 'lodash/noop';
import PropTypes from 'prop-types';
import './panel.less';
import Icon from './../icon/icon';

export default class Panel extends Component {
    constructor(props) {
        super(props);
        this.state = {
            expanded: this.props.expanded
        };
        this.togglePanelContent = this.togglePanelContent.bind(this);
    }

    togglePanelContent() {
        const {
            expanded
        } = this.state;
        const {
            id,
            onToggle
        } = this.props;

        this.setState({ expanded: !expanded });
        onToggle({
            id,
            expanded: !expanded
        });
    }

    render() {
        const {
            expanded
        } = this.state;
        const {
            children,
            id,
            subClass,
            title,
            width,
            contentHeight
        } = this.props;
        const inlineStyle = {
            width: width
        };
        const inlineStyleContent = {
            height: contentHeight
        };
        const iconType = expanded ? 'arrow-down' : 'arrow-right';
        const className = classnames(
            'tsdev-panel', { expanded: expanded }, subClass
        );
        const classNameHeader = classnames('panel-header', { expanded: expanded });
        const classNameContent = classnames('panel-content', { expanded: expanded });

        return (
            <div id={id}
                className={className}
                style={inlineStyle} >
                <div className={classNameHeader}
                    onClick={this.togglePanelContent}>
                    <div className="panel-header-toggle-icon">
                        <Icon size={20}
                            iconType={iconType} />
                    </div>
                    <div className="panel-header-title">
                        {title}
                    </div>
                </div>
                <div className={classNameContent}
                    style={inlineStyleContent}>
                    {children}
                </div>
            </div>
        );
    }
}

Panel.propTypes = {
    children: PropTypes.node,
    contentHeight: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
    ]),
    expanded: PropTypes.bool,
    id: PropTypes.string,
    onToggle: PropTypes.func,
    subClass: PropTypes.string,
    title: PropTypes.string,
    width: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
    ])
};

Panel.defaultProps = {
    children: (<div>children</div>),
    contentHeight: 250,
    expanded: false,
    id: `tsdevPanel-${Uuid.v4()}`,
    onToggle: noop,
    subClass: '',
    title: 'Panel',
    width: 500
};

Panel.displayName = 'Panel';
