import React, { Component } from 'react';
import classnames from 'classnames';
import PropTypes from 'prop-types';
import noop from 'lodash/noop';
import Uuid from 'uuid';
import './tag.less';

export default class Tag extends Component {
    constructor(props) {
        super(props);
        this.state = {
            isVisible: true
        };
        this.handleClose = this.handleClose.bind(this);
    }

    handleClose() {
        const {
            id,
            label,
            value,
            onClose,
            disabled
        } = this.props;

        /* istanbul ignore else */
        if (!disabled) {
            this.setState({ isVisible: false });
            onClose({
                id,
                label,
                value
            });
        }
    }

    render() {
        const {
            isVisible
        } = this.state;
        const {
            id,
            subClass,
            isClosable,
            showValue,
            disabled,
            labelMaxWidth,
            label,
            value
        } = this.props;
        const className = classnames(
            'tsdev-tag', { disabled }, subClass
        );
        const tagCloseId = `${id}-close`;
        const valueString = `(${value})`;
        const inlineStyleTag = {
            display: isVisible ? 'block' : 'none'
        };
        const inlineStyleClose = {
            display: isClosable ? 'block' : 'none'
        };
        const inlineStyleValue = {
            display: showValue ? 'block' : 'none'
        };
        const inlineStyleLabel = {
            maxWidth: labelMaxWidth
        };

        return (
            <div id={id}
                className={className}
                style={inlineStyleTag}>
                <div className="tsdev-tag-label"
                    style={inlineStyleLabel}>{label}</div>
                <div className="tsdev-tag-value"
                    style={inlineStyleValue}>
                    {valueString}
                </div>
                <div className="tsdev-tag-close"
                    id={tagCloseId}
                    onClick={this.handleClose}
                    style={inlineStyleClose}>&times;</div>
            </div>
        );
    }
}

Tag.propTypes = {
    disabled: PropTypes.bool,
    onClose: PropTypes.func,
    id: PropTypes.string,
    isClosable: PropTypes.bool,
    label: PropTypes.string,
    labelMaxWidth: PropTypes.number,
    showValue: PropTypes.bool,
    subClass: PropTypes.string,
    value: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
    ])
};

Tag.defaultProps = {
    disabled: false,
    onClose: noop,
    id: `tsdevTag-${Uuid.v4()}`,
    isClosable: true,
    label: 'Tag',
    labelMaxWidth: 130,
    showValue: true,
    subClass: '',
    value: '123'
};

Tag.displayName = 'Tag';
